@@ -7,7 +7,7 @@ from .models import (
 
 
 class ApplicationAdmin(admin.ModelAdmin):
-    list_display = ("name", "user", "client_type", "authorization_grant_type")
+    list_display = ("id", "name", "user", "client_type", "authorization_grant_type")
     list_filter = ("client_type", "authorization_grant_type", "skip_authorization")
     radio_fields = {
         "client_type": admin.HORIZONTAL,
@@ -23,7 +23,7 @@ class GrantAdmin(admin.ModelAdmin):
 
 class AccessTokenAdmin(admin.ModelAdmin):
     list_display = ("token", "user", "application", "expires")
-    raw_id_fields = ("user", )
+    raw_id_fields = ("user", "source_refresh_token")
 
 
 class RefreshTokenAdmin(admin.ModelAdmin):
