@@ -4,7 +4,7 @@ from oauthlib.common import generate_client_id as oauthlib_generate_client_id
 from .settings import oauth2_settings
 
 
-class BaseHashGenerator(object):
+class BaseHashGenerator:
     """
     All generators should extend this class overriding `.hash()` method.
     """
