@@ -1,5 +1,6 @@
 import base64
 import binascii
+import http.client
 import logging
 from collections import OrderedDict
 from datetime import datetime, timedelta
@@ -304,6 +305,14 @@ class OAuth2Validator(RequestValidator):
             log.exception("Introspection: Failed POST to %r in token lookup", introspection_url)
             return None
 
+        # Log an exception when response from auth server is not successful
+        if response.status_code != http.client.OK:
+            log.exception("Introspection: Failed to get a valid response "
+                          "from authentication server. Status code: {}, "
+                          "Reason: {}.".format(response.status_code,
+                                               response.reason))
+            return None
+
         try:
             content = response.json()
         except ValueError:
@@ -446,18 +455,7 @@ class OAuth2Validator(RequestValidator):
         return grant.code_challenge_method or None
 
     def save_authorization_code(self, client_id, code, request, *args, **kwargs):
-        expires = timezone.now() + timedelta(
-            seconds=oauth2_settings.AUTHORIZATION_CODE_EXPIRE_SECONDS)
-        Grant.objects.create(
-            application=request.client,
-            user=request.user,
-            code=code["code"],
-            expires=expires,
-            redirect_uri=request.redirect_uri,
-            scope=" ".join(request.scopes),
-            code_challenge=request.code_challenge or "",
-            code_challenge_method=request.code_challenge_method or ""
-        )
+        self._create_authorization_code(request, code)
 
     def rotate_refresh_token(self, request):
         """
@@ -572,6 +570,21 @@ class OAuth2Validator(RequestValidator):
             source_refresh_token=source_refresh_token,
         )
 
+    def _create_authorization_code(self, request, code, expires=None):
+        if not expires:
+            expires = timezone.now() + timedelta(seconds=oauth2_settings.AUTHORIZATION_CODE_EXPIRE_SECONDS)
+
+        return Grant.objects.create(
+            application=request.client,
+            user=request.user,
+            code=code["code"],
+            expires=expires,
+            redirect_uri=request.redirect_uri,
+            scope=" ".join(request.scopes),
+            code_challenge=request.code_challenge or "",
+            code_challenge_method=request.code_challenge_method or ""
+        )
+
     def _create_refresh_token(self, request, refresh_token_code, access_token):
         return RefreshToken.objects.create(
             user=request.user,
@@ -608,7 +621,7 @@ class OAuth2Validator(RequestValidator):
         """
         Check username and password correspond to a valid and active User
         """
-        u = authenticate(request, username=username, password=password)
+        u = authenticate(username=username, password=password)
         if u is not None and u.is_active:
             request.user = u
             return True
@@ -634,7 +647,9 @@ class OAuth2Validator(RequestValidator):
                 seconds=oauth2_settings.REFRESH_TOKEN_GRACE_PERIOD_SECONDS
             )
         )
-        rt = RefreshToken.objects.filter(null_or_recent, token=refresh_token).first()
+        rt = RefreshToken.objects.filter(null_or_recent, token=refresh_token).select_related(
+            "access_token"
+        ).first()
 
         if not rt:
             return False
