@@ -24,7 +24,9 @@ class IntrospectTokenView(ClientProtectedScopedResourceView):
     @staticmethod
     def get_token_response(token_value=None):
         try:
-            token = get_access_token_model().objects.get(token=token_value)
+            token = get_access_token_model().objects.select_related(
+                "user", "application"
+                ).get(token=token_value)
         except ObjectDoesNotExist:
             return HttpResponse(
                 content=json.dumps({"active": False}),
