@@ -34,13 +34,12 @@ class BaseTest(TestCase):
         self.test_user = UserModel.objects.create_user("test_user", "test@example.com", "123456")
         self.dev_user = UserModel.objects.create_user("dev_user", "dev@example.com", "123456")
 
-        self.application = Application(
+        self.application = Application.objects.create(
             name="test_client_credentials_app",
             user=self.dev_user,
             client_type=Application.CLIENT_PUBLIC,
             authorization_grant_type=Application.GRANT_CLIENT_CREDENTIALS,
         )
-        self.application.save()
 
         oauth2_settings._SCOPES = ["read", "write"]
         oauth2_settings._DEFAULT_SCOPES = ["read", "write"]
@@ -152,13 +151,12 @@ class TestClientResourcePasswordBased(BaseTest):
         """
 
         self.application.delete()
-        self.application = Application(
+        self.application = Application.objects.create(
             name="test_client_credentials_app",
             user=self.dev_user,
             client_type=Application.CLIENT_CONFIDENTIAL,
             authorization_grant_type=Application.GRANT_PASSWORD,
         )
-        self.application.save()
 
         token_request_data = {
             "grant_type": "password",
